# certainty-estimator

## Intro
certainty-estimator is a package used to estimate the certainty of scientfic findings. It is released with
EMNLP 2021 paper `Measuring Sentence-level and Aspect-level (Un)Certainty in Science Communications` by [Jiaxin Pei](https://jiaxin-pei.github.io/) and [David Jurgens](https://jurgens.people.si.umich.edu/).


## Install 

### Use pip
If `pip` is installed, certainty-estimator could be installed directly from it:

    pip3 install certainty-estimator

### Dependencies
	python>=3.6.0
	torch>=1.6.0
	transformers >= 3.1.0
	numpy
	math
	tqdm
	
	

Please check out this [github repo](https://github.com/Jiaxin-Pei/certainty-estimator) regarding how to use this package.
    




## Contact
Jiaxin Pei (pedropei@umich.edu)
